@@ -28,8 +28,8 @@ stepped forward in time.
 """
 
 
-__version__ = "0.5.1"
-__all__ = ["state", "qg_model", "steppers", "parameterizations"]
+__version__ = "0.6.0"
+__all__ = ["state", "qg_model", "bt_model", "steppers", "parameterizations"]
 
 
-from . import state, qg_model, steppers, parameterizations
+from . import state, qg_model, bt_model, steppers, parameterizations
